@@ -20,11 +20,11 @@
 #ifndef __ENGINE_CONST_H__
 #define __ENGINE_CONST_H__
 
-#define CONFIG_SECTION    "engine/LibThai"
+#define CONFIG_SCHEMA     "org.freedesktop.ibus.libthai"
 
-#define CONFIG_KB_LAYOUT  "kb_layout"
-#define CONFIG_ISC_MODE   "isc_mode"
-#define CONFIG_DO_CORRECT "do_correct"
+#define CONFIG_KB_LAYOUT  "kb-layout"
+#define CONFIG_ISC_MODE   "isc-mode"
+#define CONFIG_DO_CORRECT "do-correct"
 
 
 #endif /* __ENGINE_CONST_H__ */
