@@ -56,7 +56,7 @@ init (void)
   g_signal_connect (bus, "disconnected", G_CALLBACK (ibus_disconnected_cb),
                     NULL);
 	
-  ibus_libthai_init (bus);
+  ibus_libthai_init ();
 
   factory = ibus_factory_new (ibus_bus_get_connection (bus));
   g_object_ref_sink (factory);
